@@ -13,28 +13,31 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-"""
-Common shared functions.
-"""
+"""Common shared functions."""
 
+import argparse
+import logging
 import sys
 
-from loguru import logger
+logger = logging.getLogger(__name__)
 
-__version__ = "0.1.13"
+__version__ = "0.1.15"
 
 
-def setup_logger(config):
-    """
-    Configure the global logger.
+def setup_logger(config: argparse.Namespace) -> None:
+    """Configure the global logger.
 
     Args:
-        config(DotMap): Config that contains arguments
+        config(argparse.Namespace): Config that contains arguments
     """
-    logger.remove()
-    logger.add(
-        sys.stderr,
-        format="<green>{level: >5}</green>: {message}",
-        level=config.test_parsing and "DEBUG" or config.debug or "INFO",
-        colorize=True,
+    logformat = {
+        True: "%(levelname)5s: %(message)s",
+        False: "%(message)s",
+    }
+
+    logging.basicConfig(
+        level=config.debug and logging.DEBUG or logging.INFO,
+        stream=sys.stdout,
+        format=logformat[config.debug],
+        datefmt="%Y-%m-%d %H:%M:%S",
     )
