@@ -13,18 +13,22 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-from typing import Any
+"""Packpage of different e-book formats."""
 
+import argparse
+from typing import Union
+
+import txt2ebook.models.book
 from txt2ebook.formats.epub import EpubWriter
 from txt2ebook.formats.txt import TxtWriter
 from txt2ebook.helpers import load_class, to_classname
 from txt2ebook.models import Book
 
 
-def create_format(book: Book, config: dict) -> Any:
-    """
-    Factory method to create ebook formatter by format.
-    """
+def create_format(
+    book: txt2ebook.models.book.Book, config: argparse.Namespace
+) -> Union[TxtWriter, EpubWriter]:
+    """Create ebook formatter by format using factory function."""
     class_name = to_classname(config.format, "Writer")
     klass = load_class("txt2ebook.formats", class_name)
     formatter = klass(book, config)
