@@ -13,8 +13,10 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
+"""Book is a container for Volumes or Chapters."""
+
 from dataclasses import dataclass, field
-from typing import List
+from typing import List, Union
 
 from txt2ebook.models.chapter import Chapter
 from txt2ebook.models.volume import Volume
@@ -22,9 +24,7 @@ from txt2ebook.models.volume import Volume
 
 @dataclass
 class Book:
-    """
-    A book class model.
-    """
+    """A book class model."""
 
     title: str = field(default="")
     authors: List[str] = field(default_factory=List)
@@ -32,7 +32,5 @@ class Book:
     cover: str = field(default="", repr=False)
     raw_content: str = field(default="", repr=False)
     massaged_content: str = field(default="", repr=False)
-    parsed_content: List[tuple] = field(default_factory=List, repr=False)
-    volumes: List[Volume] = field(default_factory=List, repr=False)
-    chapters: List[Chapter] = field(default_factory=List, repr=False)
+    toc: List[Union[Volume, Chapter]] = field(default_factory=List, repr=False)
     structure_names: dict = field(default_factory=dict, repr=False)
