@@ -13,28 +13,40 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
+"""Chapter is a container for paragraphs."""
+
+import logging
 from dataclasses import dataclass, field
 from typing import List
 
+logger = logging.getLogger(__name__)
+
 
 @dataclass(repr=False)
 class Chapter:
-    """
-    A chapter class model.
-    """
+    """A chapter class model."""
 
     title: str = field(default="")
     raw_content: str = field(default="", repr=False)
     paragraphs: List[str] = field(default_factory=list, repr=False)
 
-    def __repr__(self):
-        """
+    def __repr__(self) -> str:
+        """Return the string representation of Chapter for debugging purpose.
+
         Returns:
           str: Debugging string for logging
         """
         # pylint: disable=bad-option-value,consider-using-f-string
-        return "{}(title='{}', raw_content='{}')".format(
-            self.__class__.__name__,
-            self.title,
-            repr(self.raw_content[0:10]),
+        return (
+            "{}(title='{}', raw_content='{}', total_paragraphs='{}')".format(
+                self.__class__.__name__,
+                self.title,
+                repr(self.raw_content[0:10]),
+                len(self.paragraphs),
+            )
         )
+
+    def add_paragraph(self, paragraph: str) -> None:
+        """Append a paragraph to the current chapter."""
+        # logger.debug("add paragraph: " + repr(paragraph[0:5]))
+        self.paragraphs.append(paragraph)
