@@ -13,6 +13,8 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
+"""Volume is a container for different Chapters."""
+
 from dataclasses import dataclass, field
 from typing import List
 
@@ -21,10 +23,12 @@ from txt2ebook.models.chapter import Chapter
 
 @dataclass
 class Volume:
-    """
-    A volume class model.
-    """
+    """A volume class model."""
 
     title: str = field(default="")
-    chapters: List[Chapter] = field(default_factory=List, repr=False)
+    chapters: List[Chapter] = field(default_factory=list, repr=False)
     raw_content: str = field(default="", repr=False)
+
+    def add_chapter(self, chapter: Chapter) -> None:
+        """Append a chapter to the current volume."""
+        self.chapters.append(chapter)
